isValidOid function

bool isValidOid(
  1. String value
)

Test if the given value is a valid OID.

Note: for performance reason, it does only the basic check.

Implementation

bool isValidOid(String value)
=> value.length == oidLength && _reOid.hasMatch(value);