PostgresqlAccessAgent class

The agent for accessing PostgreSQL.

Implemented types

Properties

access → PostgresqlAccess
The connection to the PostgreSQL server.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Entity entity, Map<String, dynamic> data) → Future
Creates a new entity with the given OID into the database. *
override
delete(Entity entity, AccessOption? option) → Future
Deletes the entity from database.
override
load(Entity entity, Iterable<String>? fields, AccessOption? option) → Future<Map<String, dynamic>?>
Loads the data of the given OID. *
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(Entity entity, Map<String, dynamic> data, Iterable<String>? fields) → Future
Updates the entity with the given OID into database. *
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited